Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(523)

Unified Diff: src/ia32/macro-assembler-ia32.cc

Issue 5985012: Rename write buffers to store buffers. (Closed) Base URL: http://v8.googlecode.com/svn/branches/experimental/gc/
Patch Set: Created 9 years, 11 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/ia32/code-stubs-ia32.cc ('k') | src/runtime.h » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/ia32/macro-assembler-ia32.cc
===================================================================
--- src/ia32/macro-assembler-ia32.cc (revision 6184)
+++ src/ia32/macro-assembler-ia32.cc (working copy)
@@ -60,23 +60,23 @@
bind(&not_in_new_space);
}
- // Load write buffer top.
- ExternalReference write_buffer = ExternalReference::write_buffer_top();
- mov(scratch, Operand::StaticVariable(write_buffer));
+ // Load store buffer top.
+ ExternalReference store_buffer = ExternalReference::store_buffer_top();
+ mov(scratch, Operand::StaticVariable(store_buffer));
// Store pointer to buffer.
mov(Operand(scratch, 0), addr);
// Increment buffer top.
add(Operand(scratch), Immediate(kPointerSize));
// Write back new top of buffer.
- mov(Operand::StaticVariable(write_buffer), scratch);
+ mov(Operand::StaticVariable(store_buffer), scratch);
// Call stub on end of buffer.
NearLabel no_overflow;
// Check for end of buffer.
- test(scratch, Immediate(WriteBuffer::kWriteBufferOverflowBit));
+ test(scratch, Immediate(StoreBuffer::kStoreBufferOverflowBit));
j(equal, &no_overflow);
- WriteBufferOverflowStub write_buffer_overflow =
- WriteBufferOverflowStub(save_fp);
- CallStub(&write_buffer_overflow);
+ StoreBufferOverflowStub store_buffer_overflow =
+ StoreBufferOverflowStub(save_fp);
+ CallStub(&store_buffer_overflow);
bind(&no_overflow);
}
« no previous file with comments | « src/ia32/code-stubs-ia32.cc ('k') | src/runtime.h » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698